@@ -19,7 +19,8 @@ def remove_redundant_correctors(input_addr: str):
 
     parser = et.XMLParser(remove_blank_text=True)
     xml = et.parse(input_addr, parser)
-    for rdg in xml.xpath('//tei:rdg', namespaces={'tei': tei_ns}):
+    rdg: et._Element
+    for rdg in xml.xpath('//tei:rdg', namespaces={'tei': tei_ns}): #type: et._Element
         wits = rdg.get('wit').split()
         cleaned_wits = clean_wits(wits)
         rdg.attrib['wit'] = cleaned_wits
